@@ -313,7 +313,6 @@ function parsePlaces(response) {
                            "city": parse(place.location.city),
                            "lat": place.location.lat,
                            "lng": place.location.lng,
-                           "hereNow": place.hereNow.count,
                            "icon": icon,
                            "venueCheckinsCount": place.stats.checkinsCount,
                            "venueUsersCount": place.stats.usersCount
@@ -545,7 +544,6 @@ function parseToDo(response) {
                            "city": parse(place.location.city),
                            "lat": place.location.lat,
                            "lng": place.location.lng,
-                           "hereNow": "",
                            "icon": icon,
                            "venueCheckinsCount": place.stats.checkinsCount,
                            "venueUsersCount": place.stats.usersCount
